Taurus Enhancement Proposals
=============================

This is the main index of the Taurus Enhancement Proposals (TEP).

Each proposal should be in a separate file and be linked in the following table

Proposals list
--------------

  Link        |  status   |        Title                                              
  ------------| --------- | ---------------------------------------------------------
  [TEP0][]   | OBSOLETE | Introducing Taurus Enhancement Proposal                  
  [TEP3][]   | ACCEPTED | Tango-Independent                                        
  [SEP5][]   | ACCEPTED  | Implementation of tests infrastructure                   
  [TEP7][]   | OBSOLETE  | Code contribution workflow                               
  [TEP8][]   | REJECTED | Remove from Taurus objects the direct Logger dependence  
  [SEP9][]   | ACCEPTED  | Compact Read+Write widgets in Taurus                     
  [SEP10][] | ACCEPTED  | Taurus separation                                        
  [SEP11][] | ACCEPTED  | Direct load of .ui files                                       
  [SEP12][] | CANDIDATE | Use python Enum instead of taurus Enumeration
  [TEP13][] | DRAFT     | Plugins support 
  [TEP14][] | ACCEPTED  | Core refactoring (quantities and configuration)
  [TEP15][] | ACCEPTED  | fragment-based slicing support in URIs
  [TEP16][] | ACCEPTED     | Moving Taurus to Github
  [TEP17][] | DRAFT   | Implement plots with pyqtgraph
  [TEP18][] | ACCEPTED | Implement support for Qt5 in taurus

[TEP0]: http://www.taurus-scada.org/tep/?TEP0.md
[TEP3]: http://www.taurus-scada.org/tep/?TEP3.md
[SEP5]: http:/www.sardana-controls.org/sep/?SEP5.md
[TEP7]: http://www.taurus-scada.org/tep/?TEP7.md
[TEP8]: http://www.taurus-scada.org/tep/?TEP8.md
[SEP9]:  http:/www.sardana-controls.org/sep/?SEP9.md
[SEP10]: http:/www.sardana-controls.org/sep/?SEP10.md
[SEP11]: http:/www.sardana-controls.org/sep/?SEP11.md
[SEP12]: http:/www.sardana-controls.org/sep/?SEP12.md
[TEP13]: http://www.taurus-scada.org/tep/?TEP13.md
[TEP14]: http://www.taurus-scada.org/tep/?TEP14.md
[TEP15]: http://www.taurus-scada.org/tep/?TEP15.md
[TEP16]: http://www.taurus-scada.org/tep/?TEP16.md
[TEP17]: https://github.com/cpascual/taurus/blob/tep17/doc/source/tep/TEP17.md
[TEP18]: http://www.taurus-scada.org/tep/?TEP18.md
